Coverage for hadal/__init__.py: 100%

1"""Top-level package for `hadal`."""

2 __version__ = "0.0.2"

3

4 from hadal.huggingface_automodel import HuggingfaceAutoModel # noqa: F401, I001

5

6 from hadal.faiss_search import FaissSearch # noqa: F401

7

8 from hadal.parallel_sentence_mining.margin_based.margin_based import MarginBasedPipeline # noqa: F401

9 from hadal.parallel_sentence_mining.margin_based.margin_based_tools import MarginBased # noqa: F401